@@ -1,5 +1,4 @@
-
-$(document).ready(function() {
+var setup_websocket = function(socket_url) {
     var pending_count = 0;
 
     function getUrlVars() {
@@ -25,8 +24,6 @@ $(document).ready(function() {
 
         if ("WebSocket" in window) {
             // Let us open a web socket
-            var socket_url = "wss://hub.fedoraproject.org:9939";
-            //var socket_url = "wss://209.132.181.16:9939";
             var ws = new WebSocket(socket_url);
             ws.onopen = function(e) {
                 // Web Socket is connected, send data using send()
@@ -35,8 +32,8 @@ $(document).ready(function() {
             };
             ws.onmessage = function (evt) {
                 pending_count = pending_count + 1;
-                $("#messages-pending").html(pending_count + " new messages.")
-                $("#messages-pending").parent().parent().parent().removeClass('hidden');
+                $("#messages-pending").html(pending_count + " new messages. Click to Show")
+                $("#messages-pending").show();
             };
             ws.onclose = function(e){ws=null;};
             ws.onerror = function(e){ws=null;WebSocketSetup(attempts + 1);};
@@ -51,13 +48,13 @@ $(document).ready(function() {
     if (window.location.search == "") {
         WebSocketSetup(1);
 
-        $("#messages-pending").parent().click(function(evt) {
+        $("#messages-pending").click(function(evt) {
             var params = getUrlVars();
             params['chrome'] = 'false';
             params['rows_per_page'] = pending_count;
             params = $.param(params, traditional=true);
             pending_count = 0;
-            $("#messages-pending").parent().parent().parent().addClass('hidden');
+            $("#messages-pending").hide();
             $.ajax({
                 url: window.location.pathname,
                 dataType: 'html',
@@ -70,4 +67,4 @@ $(document).ready(function() {
             });
         })
     }
-});
+};
